==> rc-tooltip-2.1.2.tgz: package/lib/Popup.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

/**
 * @author yiminghe@gmail.com
 */

var React = require('react');
var anim = require('css-animation');
var utils = require('./utils');
var domAlign = require('dom-align');

var Popup = (function (_React$Component) {
  function Popup() {
    _classCallCheck(this, Popup);

    _get(Object.getPrototypeOf(Popup.prototype), 'constructor', this).apply(this, arguments);
  }

  _inherits(Popup, _React$Component);

  _createClass(Popup, [{
    key: 'getRootNode',
    value: function getRootNode() {
      return React.findDOMNode(this.refs.popup);
    }
  }, {
    key: 'alignRootNode',
    value: function alignRootNode() {
      var props = this.props;
      if (props.visible) {
        var targetDomNode = React.findDOMNode(props.wrap).firstChild;
        var popupDomNode = this.getRootNode();
        var placement = props.placement;
        var points;
        if (placement && placement.points) {
          var align = domAlign(popupDomNode, targetDomNode, placement);
          popupDomNode.className = utils.getToolTipClassByPlacement(props.prefixCls, align);
        } else {
          points = ['cr', 'cl'];
          if (placement === 'right') {
            points = ['cl', 'cr'];
          } else if (placement === 'top') {
            points = ['bc', 'tc'];
          } else if (placement === 'bottom') {
            points = ['tc', 'bc'];
          }
          domAlign(popupDomNode, targetDomNode, {
            points: points
          });
        }
      }
    }
  }, {
    key: 'animateRootNode',
    value: function animateRootNode(prevProps) {
      var props = this.props;
      var transitionName = props.transitionName;
      if (!transitionName && props.animation) {
        transitionName = props.prefixCls + '-' + props.animation;
      }
      if (transitionName) {
        var domNode = this.getRootNode();
        if (props.visible && !prevProps.visible) {
          anim(domNode, transitionName + '-enter');
        } else if (!props.visible && prevProps.visible) {
          anim(domNode, transitionName + '-leave');
        }
      }
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      prevProps = prevProps || {};
      this.alignRootNode();
      this.animateRootNode(prevProps);
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.componentDidUpdate();
    }
  }, {
    key: 'render',
    value: function render() {
      var props = this.props;
      var className = utils.getToolTipClassByPlacement(props.prefixCls, props.placement);
      if (props.className) {
        className += ' ' + props.className;
      }
      var style = this.props.style;
      if (!props.visible) {
        className += ' ' + props.prefixCls + '-hidden';
      }
      var arrowClassName = props.prefixCls + '-arrow';
      var innerClassname = props.prefixCls + '-inner';
      return React.createElement(
        'div',
        { className: className,
          key: 'popup',
          ref: 'popup',
          style: style },
        React.createElement('div', { className: arrowClassName }),
        React.createElement(
          'div',
          { className: innerClassname },
          props.children
        )
      );
    }
  }]);

  return Popup;
})(React.Component);

module.exports = Popup;

==> rc-tooltip-2.2.0.tgz: package/lib/Popup.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

/**
 * @author yiminghe@gmail.com
 */

var React = require('react');
var anim = require('css-animation');
var utils = require('./utils');
var domAlign = require('dom-align');

var Popup = (function (_React$Component) {
  function Popup() {
    _classCallCheck(this, Popup);

    _get(Object.getPrototypeOf(Popup.prototype), 'constructor', this).apply(this, arguments);
  }

  _inherits(Popup, _React$Component);

  _createClass(Popup, [{
    key: 'getPopupNode',
    value: function getPopupNode() {
      return React.findDOMNode(this.refs.popup);
    }
  }, {
    key: 'alignRootNode',
    value: function alignRootNode(prevProps) {
      var props = this.props;
      if (props.visible && !prevProps.visible) {
        var targetDomNode = React.findDOMNode(props.wrap).firstChild;
        var popupDomNode = this.getPopupNode();
        var placement = props.placement;
        var points;
        if (placement && placement.points) {
          var originalClassName = utils.getToolTipClassByPlacement(props.prefixCls, placement);
          var align = domAlign(popupDomNode, targetDomNode, placement);
          var nextClassName = utils.getToolTipClassByPlacement(props.prefixCls, align);
          if (nextClassName !== originalClassName) {
            popupDomNode.className = popupDomNode.className.replace(originalClassName, nextClassName);
          }
        } else {
          points = ['cr', 'cl'];
          if (placement === 'right') {
            points = ['cl', 'cr'];
          } else if (placement === 'top') {
            points = ['bc', 'tc'];
          } else if (placement === 'bottom') {
            points = ['tc', 'bc'];
          }
          domAlign(popupDomNode, targetDomNode, {
            points: points
          });
        }
      }
    }
  }, {
    key: 'animateRootNode',
    value: function animateRootNode(prevProps) {
      var props = this.props;
      var transitionName = props.transitionName;
      if (!transitionName && props.animation) {
        transitionName = props.prefixCls + '-' + props.animation;
      }
      if (transitionName) {
        var domNode = this.getPopupNode();
        if (props.visible && !prevProps.visible) {
          anim(domNode, transitionName + '-enter');
        } else if (!props.visible && prevProps.visible) {
          anim(domNode, transitionName + '-leave');
        }
      }
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      prevProps = prevProps || {};
      this.alignRootNode(prevProps);
      this.animateRootNode(prevProps);
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.componentDidUpdate();
    }
  }, {
    key: 'render',
    value: function render() {
      var props = this.props;
      var className = utils.getToolTipClassByPlacement(props.prefixCls, props.placement);
      if (props.className) {
        className += ' ' + props.className;
      }
      var style = this.props.style;
      var maskClassName = props.prefixCls + '-mask';
      if (!props.visible) {
        className += ' ' + props.prefixCls + '-hidden';
        maskClassName += ' ' + props.prefixCls + '-mask-hidden';
      }
      var arrowClassName = props.prefixCls + '-arrow';
      var innerClassname = props.prefixCls + '-inner';
      return React.createElement(
        'div',
        null,
        props.trigger.indexOf('click') !== -1 ? React.createElement('div', { className: maskClassName, onClick: props.onClickOutside }) : null,
        React.createElement(
          'div',
          { className: className,
            ref: 'popup',
            style: style },
          React.createElement('div', { className: arrowClassName }),
          React.createElement(
            'div',
            { className: innerClassname },
            props.children
          )
        )
      );
    }
  }]);

  return Popup;
})(React.Component);

module.exports = Popup;
